[tracker/async-queries-cursor] tracker-store: squash with previous, I mismeasured it



commit b3310609e77f89c1041fb166bc1ba240844247e1
Author: Philip Van Hoof <philip codeminded be>
Date:   Wed Apr 21 12:23:13 2010 +0200

    tracker-store: squash with previous, I mismeasured it

 src/tracker-store/tracker-resources.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/tracker-store/tracker-resources.c b/src/tracker-store/tracker-resources.c
index b03b7ca..2a46166 100644
--- a/src/tracker-store/tracker-resources.c
+++ b/src/tracker-store/tracker-resources.c
@@ -230,7 +230,7 @@ query_callback (TrackerDBCursor *cursor, GError *error, gpointer user_data)
 			 * the feeling that this value was very much respected, as the size
 			 * of the DBusMessage when libdbus decided to exit() the process was
 			 * around 160 MB, and not ~ 1000 MB. So if you take 160 MB and you
 			 * devide it by 368940 you have an average string size of ~ 430
 			 * bytes plus DBusMessage's overhead. If that makes this number less
 			 * arbitrary for you, then fine.
 			 *
@@ -243,7 +243,7 @@ query_callback (TrackerDBCursor *cursor, GError *error, gpointer user_data)
 			 * total length. As far as I know are both not possible. So that for
 			 * me means that libdbus's exit() is unacceptable.*/
 
-			if (length > 368940) {
+			if (length > 2213640) {
 				g_set_error (&loop_error, TRACKER_DB_INTERFACE_ERROR, TRACKER_DB_INTERRUPTED,
 				             "resultset of the query is too large");
 				dbus_message_iter_close_container (&rows_iter, &cols_iter);
@@ -230,7 +230,7 @@ query_callback (TrackerDBCursor *cursor, GError *error, gpointer user_data)
 			 * of the DBusMessage when libdbus decided to exit() the process was
 			 * around 160 MB, and not ~ 1000 MB. So if you take 160 MB and you
-			 * devide it by 368940 you have an average string size of ~ 430
+			 * devide it by 2213640 you have an average string size of ~ 72
 			 * bytes plus DBusMessage's overhead. If that makes this number less
 			 * arbitrary for you, then fine.



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]